Installation — mode-ng 0.4.0 documentation

.. _installation:

# Installation

You can install Mode either via the Python Package Index (PyPI) or from source.

To install using `pip`::

    $ pip install -U mode-ng

.. _installing-from-source:

## Downloading and installing from source

Download the latest version of Mode from http://pypi.org/project/mode-ng

You can install it by doing the following::

    $ tar xvfz mode-ng-0.1.0.tar.gz
    $ cd mode-ng-0.1.0
    $ python setup.py build
    # python setup.py install

The last command must be executed as a privileged user if you are not currently using a virtualenv.

.. _installing-from-git:

## Using the development version

With pip

    You can install the latest snapshot of Mode using the following
    pip command::

        $ pip install https://github.com/lqhuang/mode-ng/zipball/master#egg=mode